import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Write a description of class AnimatedActor here.
 * 
 * @author Ethan Noble 
 */
public abstract class AnimatedActor extends SmoothMover {
    private int[][][] image;
    private int currentFrame;
    private int frameOne;
    private int frameTwo;
    private int animationSpeed;
    private int animationCounter = 0;
    
    private Color color;
    private int movementSpeed;
    private int size;
    
    /**
     * Constructor
     */
    public AnimatedActor(int[][][] image, int startFrame, int animationSpeed, int movementSpeed, int size, Color color) {
        this.image = image;
        this.currentFrame = startFrame;
        this.frameOne = startFrame;
        this.frameTwo = frameOne + 1;
        this.animationSpeed = animationSpeed;
        this.movementSpeed = movementSpeed;
        this.size = size;
        this.color = color;
    }
    
    /**
     * Getters and setters
     */
    public int[][][] getImageOfActor() {
        return image;
    }
    
    public int getCurrentFrame() {
        return currentFrame;
    }
    
    public int getAnimationSpeed() {
        return animationSpeed;
    }
    
    public int getAnimationCounter() {
        return animationCounter;
    }
    
    public Color getColor() {
        return color;
    }
    
    public int getSpeedOfActor() {
        return movementSpeed;
    }
    
    public int getSize() {
        return size;
    }
    
    public void setImageOfActor(int[][][] image) {
        this.image = image;
    }
    
    public void setCurrentFrame(int currentFrame) {
        this.currentFrame = currentFrame;
    }
    
    public void setAnimationSpeed(int animationSpeed) {
        this.animationSpeed = animationSpeed;
    }
    
    public void setColor(Color color) {
        this.color = color;
    }
    
    public void setSpeedOfActor(int movementSpeed) {
        this.movementSpeed = movementSpeed;
    }
    
    public void setSize(int size) {
        this.size = size;
    }
    
    /**End of getters and setters*/
    
    public void animate() {
        if (animationCounter % animationSpeed == 0) {
            if (currentFrame == frameOne) {
                currentFrame = frameTwo;
            }
            else {
                currentFrame = frameOne;
            }
        }
        
        animationCounter++;
        initializeImage();
    }
    
    public void initializeImage() {
        getImage().clear();
        
        int widthArr = image[currentFrame][0].length;
        int heightArr = image[currentFrame].length;
        
        getImage().scale(widthArr * size, heightArr * size);
        getImage().setColor(color);
        
        for (int y = 0; y < heightArr; y++) {
            for (int x = 0; x < widthArr; x++) {
                if (image[currentFrame][y][x] == 1) {
                    int widthImage = getImage().getWidth();
                    int heightImage = getImage().getHeight();
                    
                    getImage().fillRect(x * size, y * size, widthImage / widthArr, heightImage / heightArr);
                }
            }
        }
    }
}
