import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Write a description of class Ship here.
 * 
 * @author Ethan Noble
 */
public class Ship extends Actor {
    private int numberOfFragments = 25;
    private int size;
    private int movementSpeed = 7;
    private Color color;
    private int[][] image = new int[][] {
                                    {0, 1, 0},
                                    {1, 1, 1},
                                    {1, 0, 1},
                                };
    public Ship(int size, Color color) {
        this.size = size;
        this.color = color;
        
        initializeImage();
    }
    
    /**
     * Act
     */
    public void act() {
        checkKeyPress();
    }
    
    public void explode() {
        for (int i = 0; i < numberOfFragments; i++) {
            getWorld().addObject(new Fragment(color), getX(), getY());
        }
        
        MyWorld world = (MyWorld) getWorld();
        Greenfoot.playSound("explosion.wav");
        world.gameOver();
        world.removeObject(this);
    }
    
    private void checkKeyPress() {
        if (Greenfoot.isKeyDown("left") && getX() > 0) {
            setLocation(getX() - movementSpeed, getY());
        }
        if (Greenfoot.isKeyDown("right") && getX() < getWorld().getWidth() - 1) {
            setLocation(getX() + movementSpeed, getY());
        }
        if (Greenfoot.isKeyDown("space")) {
            if (getWorld().getObjects(PlayerBullet.class).size() == 0) {
                getWorld().addObject(new PlayerBullet(), getX(), getY() - getImage().getHeight());
                Greenfoot.playSound("shoot.wav");
            }
        }
    }
    
    private void initializeImage() {
        getImage().clear();
        
        int widthArr = image[0].length;
        int heightArr = image.length;
        
        getImage().scale(widthArr * size, heightArr * size);
        getImage().setColor(color);
        
        for (int y = 0; y < heightArr; y++) {
            for (int x = 0; x < widthArr; x++) {
                if (image[y][x] == 1) {
                    int widthImage = getImage().getWidth();
                    int heightImage = getImage().getHeight();
                    
                    getImage().fillRect(x * size, y * size, widthImage / widthArr, heightImage / heightArr);
                }
            }
        }
    }
}
